Release and Version History
===========================

0.0.20 (TODO)
~~~~~~~~~~~~~~~~~~
**Features and Improvements**

- make docfly a sphinx extensions. (Sorry, now I don't know how yet)

**Minor Improvements**

**Bugfixes**

**Miscellaneous**


0.0.19 (TODO)
~~~~~~~~~~~~~~~~~~
**Features and Improvements**

- make docfly a sphinx extensions. (Sorry, now I don't know how yet)

**Minor Improvements**

**Bugfixes**

**Miscellaneous**


0.0.18 (2020-04-15)
~~~~~~~~~~~~~~~~~~
**Features and Improvements**

- allow ``.. autotoctree::`` to detect header line if it use ``.. include:: other-file.rst`` at the top, then it exam after the ``other-file.rst`` merged into the original rst file.


0.0.17 (2018-11-30)
~~~~~~~~~~~~~~~~~~
**Now I finally know how to write sphinx extension correctly!**

**Features and Improvements**

- now docfly can be used as a sphinx extensions.
- ``.. articles::`` can be replaced by ``.. autotoctree::``


0.0.16 (2018-10-16)
~~~~~~~~~~~~~~~~~~~
**Features and Improvements**

- Automatic API Reference Doc Generation.
- Easy Table of Content directive Generation (``.. toctree::``).


0.0.1 (2015-08-13)
~~~~~~~~~~~~~~~~~~
- First release